@@ -35,6 +35,19 @@ class DokuHTTPClient extends HTTPClient {
         $this->proxy_pass   = conf_decodeString($conf['proxy']['pass']);
         $this->proxy_ssl    = $conf['proxy']['ssl'];
         $this->proxy_except = $conf['proxy']['except'];
+
+        // allow enabling debugging via URL parameter (if debugging allowed)
+        if($conf['allowdebug']) {
+            if(
+                isset($_REQUEST['httpdebug']) ||
+                (
+                    isset($_SERVER['HTTP_REFERER']) &&
+                    strpos($_SERVER['HTTP_REFERER'], 'httpdebug') !== false
+                )
+            ) {
+                $this->debug = true;
+            }
+        }
     }
 
 
@@ -44,6 +57,12 @@ class DokuHTTPClient extends HTTPClient {
      * @triggers HTTPCLIENT_REQUEST_SEND
      * @author   Andreas Gohr <andi@splitbrain.org>
      */
+    /**
+     * @param string $url
+     * @param string|array $data the post data either as array or raw data
+     * @param string $method
+     * @return bool
+     */
     function sendRequest($url,$data='',$method='GET'){
         $httpdata = array('url'    => $url,
                           'data'   => $data,
@@ -61,6 +80,9 @@ class DokuHTTPClient extends HTTPClient {
 
 }
 
+/**
+ * Class HTTPClientException
+ */
 class HTTPClientException extends Exception { }
 
 /**
@@ -88,7 +110,7 @@ class HTTPClient {
     var $header_regexp; // if set this RE must match against the headers, else abort
     var $headers;
     var $debug;
-    var $start = 0; // for timings
+    var $start = 0.0; // for timings
     var $keep_alive = true; // keep alive rocks
 
     // don't set these, read on error
@@ -150,6 +172,8 @@ class HTTPClient {
      *
      * @param  string $url       The URL to fetch
      * @param  bool   $sloppy304 Return body on 304 not modified
+     * @return false|string  response body, false on error
+     *
      * @author Andreas Gohr <andi@splitbrain.org>
      */
     function get($url,$sloppy304=false){
@@ -170,6 +194,8 @@ class HTTPClient {
      * @param  string $url       The URL to fetch
      * @param  array  $data      Associative array of parameters
      * @param  bool   $sloppy304 Return body on 304 not modified
+     * @return false|string  response body, false on error
+     *
      * @author Andreas Gohr <andi@splitbrain.org>
      */
     function dget($url,$data,$sloppy304=false){
@@ -187,6 +213,9 @@ class HTTPClient {
      *
      * Returns the resulting page or false on an error;
      *
+     * @param  string $url       The URL to fetch
+     * @param  array  $data      Associative array of parameters
+     * @return false|string  response body, false on error
      * @author Andreas Gohr <andi@splitbrain.org>
      */
     function post($url,$data){
@@ -208,6 +237,7 @@ class HTTPClient {
      * @param  mixed  $data   - the post data either as array or raw data
      * @param  string $method - HTTP Method usually GET or POST.
      * @return bool - true on success
+     *
      * @author Andreas Goetz <cpuidle@gmx.de>
      * @author Andreas Gohr <andi@splitbrain.org>
      */
@@ -215,6 +245,9 @@ class HTTPClient {
         $this->start  = $this->_time();
         $this->error  = '';
         $this->status = 0;
+        $this->status = 0;
+        $this->resp_body = '';
+        $this->resp_headers = array();
 
         // don't accept gzip if truncated bodies might occur
         if($this->max_bodysize &&
@@ -239,14 +272,21 @@ class HTTPClient {
             $server      = $this->proxy_host;
             $port        = $this->proxy_port;
             if (empty($port)) $port = 8080;
+            $use_tls     = $this->proxy_ssl;
         }else{
             $request_url = $path;
-            $server      = $server;
             if (!isset($port)) $port = ($uri['scheme'] == 'https') ? 443 : 80;
+            $use_tls     = ($uri['scheme'] == 'https');
         }
 
         // add SSL stream prefix if needed - needs SSL support in PHP
-        if($port == 443 || $this->proxy_ssl) $server = 'ssl://'.$server;
+        if($use_tls) {
+            if(!in_array('ssl', stream_get_transports())) {
+                $this->status = -200;
+                $this->error = 'This PHP version does not support SSL - cannot connect to server';
+            }
+            $server = 'ssl://'.$server;
+        }
 
         // prepare headers
         $headers               = $this->headers;
@@ -254,11 +294,7 @@ class HTTPClient {
         if(!empty($uri['port'])) $headers['Host'].= ':'.$uri['port'];
         $headers['User-Agent'] = $this->agent;
         $headers['Referer']    = $this->referer;
-        if ($this->keep_alive) {
-            $headers['Connection'] = 'Keep-Alive';
-        } else {
-            $headers['Connection'] = 'Close';
-        }
+
         if($method == 'POST'){
             if(is_array($data)){
                 if($headers['Content-Type'] == 'multipart/form-data'){
@@ -270,7 +306,6 @@ class HTTPClient {
                 }
             }
             $headers['Content-Length'] = strlen($data);
-            $rmethod = 'POST';
         }elseif($method == 'GET'){
             $data = ''; //no data allowed on GET requests
         }
@@ -299,6 +334,21 @@ class HTTPClient {
                 return false;
             }
 
+            // try establish a CONNECT tunnel for SSL
+            try {
+                if($this->_ssltunnel($socket, $request_url)){
+                    // no keep alive for tunnels
+                    $this->keep_alive = false;
+                    // tunnel is authed already
+                    if(isset($headers['Proxy-Authentication'])) unset($headers['Proxy-Authentication']);
+                }
+            } catch (HTTPClientException $e) {
+                $this->status = $e->getCode();
+                $this->error = $e->getMessage();
+                fclose($socket);
+                return false;
+            }
+
             // keep alive?
             if ($this->keep_alive) {
                 self::$connections[$connectionId] = $socket;
@@ -307,9 +357,18 @@ class HTTPClient {
             }
         }
 
+        if ($this->keep_alive && !$this->proxy_host) {
+            // RFC 2068, section 19.7.1: A client MUST NOT send the Keep-Alive
+            // connection token to a proxy server. We still do keep the connection the
+            // proxy alive (well except for CONNECT tunnels)
+            $headers['Connection'] = 'Keep-Alive';
+        } else {
+            $headers['Connection'] = 'Close';
+        }
+
         try {
             //set non-blocking
-            stream_set_blocking($socket, false);
+            stream_set_blocking($socket, 0);
 
             // build request
             $request  = "$method $request_url HTTP/".$this->http.HTTP_NL;
@@ -342,7 +401,7 @@ class HTTPClient {
 
             // get Status
             if (!preg_match('/^HTTP\/(\d\.\d)\s*(\d+).*?\n/', $r_headers, $m))
-                throw new HTTPClientException('Server returned bad answer');
+                throw new HTTPClientException('Server returned bad answer '.$r_headers);
 
             $this->status = $m[2];
 
@@ -424,12 +483,35 @@ class HTTPClient {
 
                     if ($chunk_size > 0) {
                         $r_body .= $this->_readData($socket, $chunk_size, 'chunk');
-                        $byte = $this->_readData($socket, 2, 'chunk'); // read trailing \r\n
+                        $this->_readData($socket, 2, 'chunk'); // read trailing \r\n
                     }
                 } while ($chunk_size && !$abort);
-            }elseif($this->max_bodysize){
-                // read just over the max_bodysize
-                $r_body = $this->_readData($socket, $this->max_bodysize+1, 'response', true);
+            }elseif(isset($this->resp_headers['content-length']) && !isset($this->resp_headers['transfer-encoding'])){
+                /* RFC 2616
+                 * If a message is received with both a Transfer-Encoding header field and a Content-Length
+                 * header field, the latter MUST be ignored.
+                 */
+
+                // read up to the content-length or max_bodysize
+                // for keep alive we need to read the whole message to clean up the socket for the next read
+                if(!$this->keep_alive && $this->max_bodysize && $this->max_bodysize < $this->resp_headers['content-length']){
+                    $length = $this->max_bodysize;
+                }else{
+                    $length = $this->resp_headers['content-length'];
+                }
+
+                $r_body = $this->_readData($socket, $length, 'response (content-length limited)', true);
+            }elseif( !isset($this->resp_headers['transfer-encoding']) && $this->max_bodysize && !$this->keep_alive){
+                $r_body = $this->_readData($socket, $this->max_bodysize, 'response (content-length limited)', true);
+            }else{
+                // read entire socket
+                while (!feof($socket)) {
+                    $r_body .= $this->_readData($socket, 4096, 'response (unlimited)', true);
+                }
+            }
+
+            // recheck body size, we might had to read the whole body, so we abort late or trim here
+            if($this->max_bodysize){
                 if(strlen($r_body) > $this->max_bodysize){
                     if ($this->max_bodysize_abort) {
                         throw new HTTPClientException('Allowed response size exceeded');
@@ -437,16 +519,6 @@ class HTTPClient {
                         $this->error = 'Allowed response size exceeded';
                     }
                 }
-            }elseif(isset($this->resp_headers['content-length']) &&
-                    !isset($this->resp_headers['transfer-encoding'])){
-                // read up to the content-length
-                $r_body = $this->_readData($socket, $this->resp_headers['content-length'], 'response', true);
-            }else{
-                // read entire socket
-                $r_size = 0;
-                while (!feof($socket)) {
-                    $r_body .= $this->_readData($socket, 4096, 'response', true);
-                }
             }
 
         } catch (HTTPClientException $err) {
@@ -461,7 +533,6 @@ class HTTPClient {
         if (!$this->keep_alive ||
                 (isset($this->resp_headers['connection']) && $this->resp_headers['connection'] == 'Close')) {
             // close socket
-            $status = socket_get_status($socket);
             fclose($socket);
             unset(self::$connections[$connectionId]);
         }
@@ -484,20 +555,79 @@ class HTTPClient {
         return true;
     }
 
+    /**
+     * Tries to establish a CONNECT tunnel via Proxy
+     *
+     * Protocol, Servername and Port will be stripped from the request URL when a successful CONNECT happened
+     *
+     * @param resource &$socket
+     * @param string   &$requesturl
+     * @throws HTTPClientException when a tunnel is needed but could not be established
+     * @return bool true if a tunnel was established
+     */
+    function _ssltunnel(&$socket, &$requesturl){
+        if(!$this->proxy_host) return false;
+        $requestinfo = parse_url($requesturl);
+        if($requestinfo['scheme'] != 'https') return false;
+        if(!$requestinfo['port']) $requestinfo['port'] = 443;
+
+        // build request
+        $request  = "CONNECT {$requestinfo['host']}:{$requestinfo['port']} HTTP/1.0".HTTP_NL;
+        $request .= "Host: {$requestinfo['host']}".HTTP_NL;
+        if($this->proxy_user) {
+            $request .= 'Proxy-Authorization: Basic '.base64_encode($this->proxy_user.':'.$this->proxy_pass).HTTP_NL;
+        }
+        $request .= HTTP_NL;
+
+        $this->_debug('SSL Tunnel CONNECT',$request);
+        $this->_sendData($socket, $request, 'SSL Tunnel CONNECT');
+
+        // read headers from socket
+        $r_headers = '';
+        do{
+            $r_line = $this->_readLine($socket, 'headers');
+            $r_headers .= $r_line;
+        }while($r_line != "\r\n" && $r_line != "\n");
+
+        $this->_debug('SSL Tunnel Response',$r_headers);
+        if(preg_match('/^HTTP\/1\.[01] 200/i',$r_headers)){
+            // set correct peer name for verification (enabled since PHP 5.6)
+            stream_context_set_option($socket, 'ssl', 'peer_name', $requestinfo['host']);
+
+            // because SSLv3 is mostly broken, we try TLS connections here first.
+            // according to  https://github.com/splitbrain/dokuwiki/commit/c05ef534 we had problems with certain
+            // setups with this solution before, but we have no usable test for that and TLS should be the more
+            // common crypto by now
+            if (@stream_socket_enable_crypto($socket, true, STREAM_CRYPTO_METHOD_TLS_CLIENT)) {
+                $requesturl = $requestinfo['path'].
+                  (!empty($requestinfo['query'])?'?'.$requestinfo['query']:'');
+                return true;
+            }
+
+            // if the above failed, this will most probably not work either, but we can try
+            if (@stream_socket_enable_crypto($socket, true, STREAM_CRYPTO_METHOD_SSLv3_CLIENT)) {
+                $requesturl = $requestinfo['path'].
+                  (!empty($requestinfo['query'])?'?'.$requestinfo['query']:'');
+                return true;
+            }
+
+            throw new HTTPClientException('Failed to set up crypto for secure connection to '.$requestinfo['host'], -151);
+        }
+
+        throw new HTTPClientException('Failed to establish secure proxy connection', -150);
+    }
+
     /**
      * Safely write data to a socket
      *
-     * @param  handle $socket     An open socket handle
-     * @param  string $data       The data to write
-     * @param  string $message    Description of what is being read
+     * @param  resource $socket     An open socket handle
+     * @param  string   $data       The data to write
+     * @param  string   $message    Description of what is being read
+     * @throws HTTPClientException
+     *
      * @author Tom N Harris <tnharris@whoopdedo.org>
      */
     function _sendData($socket, $data, $message) {
-        // select parameters
-        $sel_r = null;
-        $sel_w = array($socket);
-        $sel_e = null;
-
         // send request
         $towrite = strlen($data);
         $written = 0;
@@ -509,15 +639,21 @@ class HTTPClient {
             if(feof($socket))
                 throw new HTTPClientException("Socket disconnected while writing $message");
 
-            // wait for stream ready or timeout
-            self::selecttimeout($this->timeout - $time_used, $sec, $usec);
-            if(@stream_select($sel_r, $sel_w, $sel_e, $sec, $usec) !== false){
-                // write to stream
-                $nbytes = fwrite($socket, substr($data,$written,4096));
-                if($nbytes === false)
-                    throw new HTTPClientException("Failed writing to socket while sending $message", -100);
-                $written += $nbytes;
+            // select parameters
+            $sel_r = null;
+            $sel_w = array($socket);
+            $sel_e = null;
+            // wait for stream ready or timeout (1sec)
+            if(@stream_select($sel_r,$sel_w,$sel_e,1) === false){
+                 usleep(1000);
+                 continue;
             }
+
+            // write to stream
+            $nbytes = fwrite($socket, substr($data,$written,4096));
+            if($nbytes === false)
+                throw new HTTPClientException("Failed writing to socket while sending $message", -100);
+            $written += $nbytes;
         }
     }
 
@@ -527,18 +663,16 @@ class HTTPClient {
      * Reads up to a given number of bytes or throws an exception if the
      * response times out or ends prematurely.
      *
-     * @param  handle $socket     An open socket handle in non-blocking mode
-     * @param  int    $nbytes     Number of bytes to read
-     * @param  string $message    Description of what is being read
-     * @param  bool   $ignore_eof End-of-file is not an error if this is set
+     * @param  resource $socket     An open socket handle in non-blocking mode
+     * @param  int      $nbytes     Number of bytes to read
+     * @param  string   $message    Description of what is being read
+     * @param  bool     $ignore_eof End-of-file is not an error if this is set
+     * @throws HTTPClientException
+     * @return string
+     *
      * @author Tom N Harris <tnharris@whoopdedo.org>
      */
     function _readData($socket, $nbytes, $message, $ignore_eof = false) {
-        // select parameters
-        $sel_r = array($socket);
-        $sel_w = null;
-        $sel_e = null;
-
         $r_data = '';
         // Does not return immediately so timeout and eof can be checked
         if ($nbytes < 0) $nbytes = 0;
@@ -547,8 +681,8 @@ class HTTPClient {
             $time_used = $this->_time() - $this->start;
             if ($time_used > $this->timeout)
                 throw new HTTPClientException(
-                        sprintf('Timeout while reading %s (%.3fs)', $message, $time_used),
-                        -100);
+                        sprintf('Timeout while reading %s after %d bytes (%.3fs)', $message,
+                                strlen($r_data), $time_used), -100);
             if(feof($socket)) {
                 if(!$ignore_eof)
                     throw new HTTPClientException("Premature End of File (socket) while reading $message");
@@ -556,15 +690,21 @@ class HTTPClient {
             }
 
             if ($to_read > 0) {
-                // wait for stream ready or timeout
-                self::selecttimeout($this->timeout - $time_used, $sec, $usec);
-                if(@stream_select($sel_r, $sel_w, $sel_e, $sec, $usec) !== false){
-                    $bytes = fread($socket, $to_read);
-                    if($bytes === false)
-                        throw new HTTPClientException("Failed reading from socket while reading $message", -100);
-                    $r_data .= $bytes;
-                    $to_read -= strlen($bytes);
+                // select parameters
+                $sel_r = array($socket);
+                $sel_w = null;
+                $sel_e = null;
+                // wait for stream ready or timeout (1sec)
+                if(@stream_select($sel_r,$sel_w,$sel_e,1) === false){
+                     usleep(1000);
+                     continue;
                 }
+
+                $bytes = fread($socket, $to_read);
+                if($bytes === false)
+                    throw new HTTPClientException("Failed reading from socket while reading $message", -100);
+                $r_data .= $bytes;
+                $to_read -= strlen($bytes);
             }
         } while ($to_read > 0 && strlen($r_data) < $nbytes);
         return $r_data;
@@ -575,31 +715,35 @@ class HTTPClient {
      *
      * Always returns a complete line, including the terminating \n.
      *
-     * @param  handle $socket     An open socket handle in non-blocking mode
-     * @param  string $message    Description of what is being read
+     * @param  resource $socket     An open socket handle in non-blocking mode
+     * @param  string   $message    Description of what is being read
+     * @throws HTTPClientException
+     * @return string
+     *
      * @author Tom N Harris <tnharris@whoopdedo.org>
      */
     function _readLine($socket, $message) {
-        // select parameters
-        $sel_r = array($socket);
-        $sel_w = null;
-        $sel_e = null;
-
         $r_data = '';
         do {
             $time_used = $this->_time() - $this->start;
             if ($time_used > $this->timeout)
                 throw new HTTPClientException(
-                        sprintf('Timeout while reading %s (%.3fs)', $message, $time_used),
+                        sprintf('Timeout while reading %s (%.3fs) >%s<', $message, $time_used, $r_data),
                         -100);
             if(feof($socket))
                 throw new HTTPClientException("Premature End of File (socket) while reading $message");
 
-            // wait for stream ready or timeout
-            self::selecttimeout($this->timeout - $time_used, $sec, $usec);
-            if(@stream_select($sel_r, $sel_w, $sel_e, $sec, $usec) !== false){
-                $r_data = fgets($socket, 1024);
+            // select parameters
+            $sel_r = array($socket);
+            $sel_w = null;
+            $sel_e = null;
+            // wait for stream ready or timeout (1sec)
+            if(@stream_select($sel_r,$sel_w,$sel_e,1) === false){
+                 usleep(1000);
+                 continue;
             }
+
+            $r_data = fgets($socket, 1024);
         } while (!preg_match('/\n$/',$r_data));
         return $r_data;
     }
@@ -607,10 +751,29 @@ class HTTPClient {
     /**
      * print debug info
      *
+     * Uses _debug_text or _debug_html depending on the SAPI name
+     *
      * @author Andreas Gohr <andi@splitbrain.org>
+     *
+     * @param string $info
+     * @param mixed  $var
      */
     function _debug($info,$var=null){
         if(!$this->debug) return;
+        if(php_sapi_name() == 'cli'){
+            $this->_debug_text($info, $var);
+        }else{
+            $this->_debug_html($info, $var);
+        }
+    }
+
+    /**
+     * print debug info as HTML
+     *
+     * @param string $info
+     * @param mixed  $var
+     */
+    function _debug_html($info, $var=null){
         print '<b>'.$info.'</b> '.($this->_time() - $this->start).'s<br />';
         if(!is_null($var)){
             ob_start();
@@ -621,28 +784,37 @@ class HTTPClient {
         }
     }
 
+    /**
+     * prints debug info as plain text
+     *
+     * @param string $info
+     * @param mixed  $var
+     */
+    function _debug_text($info, $var=null){
+        print '*'.$info.'* '.($this->_time() - $this->start)."s\n";
+        if(!is_null($var)) print_r($var);
+        print "\n-----------------------------------------------\n";
+    }
+
     /**
      * Return current timestamp in microsecond resolution
+     *
+     * @return float
      */
     static function _time(){
         list($usec, $sec) = explode(" ", microtime());
         return ((float)$usec + (float)$sec);
     }
 
-    /**
-     * Calculate seconds and microseconds
-     */
-    static function selecttimeout($time, &$sec, &$usec){
-        $sec = floor($time);
-        $usec = (int)(($time - $sec) * 1000000);
-    }
-
     /**
      * convert given header string to Header array
      *
      * All Keys are lowercased.
      *
      * @author Andreas Gohr <andi@splitbrain.org>
+     *
+     * @param string $string
+     * @return array
      */
     function _parseHeaders($string){
         $headers = array();
@@ -671,11 +843,14 @@ class HTTPClient {
      * convert given header array to header string
      *
      * @author Andreas Gohr <andi@splitbrain.org>
+     *
+     * @param array $headers
+     * @return string
      */
     function _buildHeaders($headers){
         $string = '';
         foreach($headers as $key => $value){
-            if(empty($value)) continue;
+            if($value === '') continue;
             $string .= $key.': '.$value.HTTP_NL;
         }
         return $string;
@@ -685,6 +860,8 @@ class HTTPClient {
      * get cookies as http header string
      *
      * @author Andreas Goetz <cpuidle@gmx.de>
+     *
+     * @return string
      */
     function _getCookies(){
         $headers = '';
@@ -692,7 +869,7 @@ class HTTPClient {
             $headers .= "$key=$val; ";
         }
         $headers = substr($headers, 0, -2);
-        if ($headers !== '') $headers = "Cookie: $headers".HTTP_NL;
+        if ($headers) $headers = "Cookie: $headers".HTTP_NL;
         return $headers;
     }
 
@@ -700,14 +877,12 @@ class HTTPClient {
      * Encode data for posting
      *
      * @author Andreas Gohr <andi@splitbrain.org>
+     *
+     * @param array $data
+     * @return string
      */
     function _postEncode($data){
-        $url = '';
-        foreach($data as $key => $val){
-            if($url) $url .= '&';
-            $url .= urlencode($key).'='.urlencode($val);
-        }
-        return $url;
+        return http_build_query($data,'','&');
     }
 
     /**
@@ -715,6 +890,9 @@ class HTTPClient {
      *
      * @fixme use of urlencode might be wrong here
      * @author Andreas Gohr <andi@splitbrain.org>
+     *
+     * @param array $data
+     * @return string
      */
     function _postMultipartEncode($data){
         $boundary = '--'.$this->boundary;
@@ -743,6 +921,8 @@ class HTTPClient {
     /**
      * Generates a unique identifier for a connection.
      *
+     * @param  string $server
+     * @param  string $port
      * @return string unique identifier
      */
     function _uniqueConnectionId($server, $port) {
