@@ -1,21 +1,18 @@
 <?php
+
 /**
- * th language file
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
- * This file was initially built by fetching translations from other
- * Wiki projects. See the @url lines below. Additional translations
- * and fixes where done for DokuWiki by the people mentioned in the
- * lines starting with @author
- *
- * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesTh.php?view=co
  * @author Komgrit Niyomrath <n.komgrit@gmail.com>
  * @author Arthit Suriyawongkul <arthit@gmail.com>
  * @author Kittithat Arnontavilas <mrtomyum@gmail.com>
  * @author Thanasak Sompaisansin <jombthep@gmail.com>
+ * @author Yuthana Tantirungrotechai <yt203y@gmail.com>
+ * @author Amnuay <amnuay@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
-$lang['doublequoteopening']    = '“	';
+$lang['doublequoteopening']    = '“';
 $lang['doublequoteclosing']    = '”';
 $lang['singlequoteopening']    = '‘';
 $lang['singlequoteclosing']    = '’';
@@ -43,17 +40,21 @@ $lang['btn_update']            = 'ปรับปรุง';
 $lang['btn_delete']            = 'ลบ';
 $lang['btn_back']              = 'ย้อนกลับ';
 $lang['btn_backlink']          = 'หน้าที่ลิงก์มา';
-$lang['btn_backtomedia']       = 'กลับไปยังหน้าเลือกไฟล์สื่อ';
 $lang['btn_subscribe']         = 'เฝ้าดู';
-$lang['btn_unsubscribe']       = 'เลิกเฝ้าดู';
 $lang['btn_profile']           = 'แก้ข้อมูลผู้ใช้';
 $lang['btn_reset']             = 'เริ่มใหม่';
+$lang['btn_resendpwd']         = 'ตั้งพาสเวิร์ดใหม่';
 $lang['btn_draft']             = 'แก้ไขเอกสารฉบับร่าง';
 $lang['btn_recover']           = 'กู้คืนเอกสารฉบับร่าง';
 $lang['btn_draftdel']          = 'ลบเอกสารฉบับร่าง';
 $lang['btn_revert']            = 'กู้คืน';
 $lang['btn_register']          = 'สร้างบัญชีผู้ใช้';
-$lang['loggedinas']            = 'ลงชื่อเข้าใช้เป็น';
+$lang['btn_apply']             = 'นำไปใช้';
+$lang['btn_media']             = 'ส่วนจัดการสื่อและไฟล์';
+$lang['btn_deleteuser']        = 'ลบบัญชีผู้ใช้งานของฉัน';
+$lang['btn_img_backto']        = 'กลับไปยัง %s';
+$lang['btn_mediaManager']      = 'ดูในส่วนจัดการสื่อและไฟล์';
+$lang['loggedinas']            = 'ลงชื่อเข้าใช้เป็น:';
 $lang['user']                  = 'ชื่อผู้ใช้:';
 $lang['pass']                  = 'รหัสผ่าน';
 $lang['newpass']               = 'รหัสผ่านใหม่';
@@ -64,13 +65,16 @@ $lang['fullname']              = 'ชื่อจริง:';
 $lang['email']                 = 'อีเมล:';
 $lang['profile']               = 'ข้อมูลส่วนตัวผู้ใช้';
 $lang['badlogin']              = 'ขัดข้อง:';
+$lang['badpassconfirm']        = 'พาสเวิร์ดไม่ถูกต้อง';
 $lang['minoredit']             = 'เป็นการแก้ไขเล็กน้อย';
 $lang['draftdate']             = 'บันทึกฉบับร่างเมื่อ';
 $lang['nosecedit']             = 'ในช่วงเวลาที่ผ่านมานี้เพจถูกแก้ไขไปแล้ว, เนื้อหาในเซคชั่นนี้ไม่ทันสมัย กรุณาโหลดเพจใหม่ทั้งหน้าแทน';
+$lang['searchcreatepage']      = 'ถ้าคุณไม่พบสิ่งที่คนมองหา คุณสามารถเลือกที่จะสร้าง หรือแก้ไขชื่อเพจหลังจากดูผลสืบค้นแล้วด้วยปุ่มที่เหมาะสม';
 $lang['regmissing']            = 'ขออภัย คุณต้องกรอกให้ครบทุกช่อง';
 $lang['reguexists']            = 'ชื่อบัญชีที่ใส่นั้นมีผู้อื่นได้ใช้แล้ว กรุณาเลือกชื่อผู้ใช้อื่น';
 $lang['regsuccess']            = 'ผู้ใช้ถูกสร้างแล้ว และรหัสผ่านได้ถูกส่งไปทางอีเมลแล้ว';
 $lang['regsuccess2']           = 'ชื่อบัญชีได้ถูกสร้างขึ้น';
+$lang['regfail']               = 'การสร้างผู้ใช้ไม่สำเร็จ';
 $lang['regmailfail']           = 'ดูเหมือนจะมีข้อผิดพลาดในการส่งรหัสผ่านทางเมล์ กรุณาติดต่อผู้ดูแลระบบ';
 $lang['regbadmail']            = 'รูปแบบอีเมลไม่ถูกต้อง ให้ใส่อีเมลให้ถูกต้องตามรูปแบบอีเมล หรือให้ทำช่องอีเมลให้ว่างแทน';
 $lang['regbadpass']            = 'รหัสผ่านที่ใส่ไม่ถูกต้อง';
@@ -80,8 +84,15 @@ $lang['profna']                = 'วิกินี้ไม่รองรั
 $lang['profnochange']          = 'ไม่มีการเปลี่ยนแปลงข้อมูลส่วนตัว';
 $lang['profnoempty']           = 'ไม่อนุญาติให้เว้นว่างชื่อ หรืออีเมล';
 $lang['profchanged']           = 'ปรับปรุงข้อมูลส่วนตัวผู้ใช้สำเร็จ';
+$lang['profnodelete']          = 'วิกินี้ไม่รองรับการลบบัญชีผู้ใช้งาน';
+$lang['profdeleteuser']        = 'ลบบัญชีผู้ใช้งาน';
+$lang['profdeleted']           = 'บัญชีผู้ใช้งานของคุณได้ถูกลบออกจากวิกิแล้ว';
+$lang['profconfdelete']        = 'ฉันอยากลบบัญชีผู้ใช้งานของฉันจากวิกินี้ <br/> การดำเนินการนี้ไม่สามารถแก้ไขคืนได้ ';
+$lang['profconfdeletemissing'] = 'ท่านไม่ได้ยืนยันในช่องยืนยัน';
+$lang['proffail']              = 'ข้อมูลผู้ใช้ไม่เป็นปัจจุบัน';
 $lang['pwdforget']             = 'ลืมรหัสผ่านหรือ? เอาอันใหม่สิ';
 $lang['resendna']              = 'วิกินี้ไม่รองรับการส่งรหัสผ่านซ้ำ';
+$lang['resendpwd']             = 'สร้างรหัสผ่านใหม่สำหรับ';
 $lang['resendpwdmissing']      = 'ขออภัย, คุณต้องกรอกทุกช่อง';
 $lang['resendpwdnouser']       = 'ขออภัย, เราไม่พบผู้ใช้คนนี้ในฐานข้อมูลของเรา';
 $lang['resendpwdbadauth']      = 'ขออภัย, รหัสนี้ยังใช้ไม่ได้ กรุณาตรวจสอบว่าคุณกดลิ้งค์ยืนยันแล้ว';
@@ -91,17 +102,37 @@ $lang['license']               = 'เว้นแต่จะได้แจ้
 $lang['licenseok']             = 'โปรดทราบ: เมื่อเริ่มแก้ไขหน้านี้ ถือว่าคุณตกลงให้สิทธิ์กับเนื้อหาของคุณอยู่ภายใต้สัญญาอนุญาตินี้';
 $lang['searchmedia']           = 'สืบค้นไฟล์ชื่อ:';
 $lang['searchmedia_in']        = 'สืบค้นใน %s';
-$lang['txt_upload']            = 'เลือกไฟล์ที่จะอัพโหลด';
-$lang['txt_filename']          = 'อัพโหลดเป็น(ตัวเลือก)';
+$lang['txt_upload']            = 'เลือกไฟล์ที่จะอัพโหลด:';
+$lang['txt_filename']          = 'อัพโหลดเป็น(ตัวเลือก):';
 $lang['txt_overwrt']           = 'เขียนทับไฟล์ที่มีอยู่แล้ว';
-$lang['lockedby']              = 'ตอนนี้ถูกล๊อคโดย';
-$lang['lockexpire']            = 'การล๊อคจะหมดอายุเมื่อ';
-$lang['js']['willexpire']            = 'การล๊อคเพื่อแก้ไขหน้านี้กำลังจะหมดเวลาในอีก \n นาที เพื่อที่จะหลีกเลี่ยงข้อขัดแย้งให้ใช้ปุ่ม "Preview" เพื่อรีเซ็ทเวลาใหม่';
+$lang['maxuploadsize']         = 'อัพโหลด สูงสุด %s ต่อไฟล์';
+$lang['lockedby']              = 'ตอนนี้ถูกล๊อคโดย:';
+$lang['lockexpire']            = 'การล๊อคจะหมดอายุเมื่อ:';
+$lang['js']['willexpire']      = 'การล๊อคเพื่อแก้ไขหน้านี้กำลังจะหมดเวลาในอีก \n นาที เพื่อที่จะหลีกเลี่ยงข้อขัดแย้งให้ใช้ปุ่ม "Preview" เพื่อรีเซ็ทเวลาใหม่';
 $lang['js']['notsavedyet']     = 'การแก้ไขที่ไม่ได้บันทึกจะสูญหาย \n ต้องการทำต่อจริงๆหรือ?';
+$lang['js']['searchmedia']     = 'ค้นหาไฟล์';
+$lang['js']['keepopen']        = 'เปิดหน้าต่างไว้ระหว่างที่เลือก';
+$lang['js']['hidedetails']     = 'ซ่อนรายละเอียด';
+$lang['js']['mediatitle']      = 'กำหนดข้อมูลลิงค์';
+$lang['js']['mediadisplay']    = 'ชนิดของลิงค์';
+$lang['js']['mediaalign']      = 'การจัดวาง';
+$lang['js']['mediasize']       = 'ขนาดรูปภาพ';
+$lang['js']['mediatarget']     = 'เป้าหมายของลิงค์';
+$lang['js']['mediaclose']      = 'ปิด';
+$lang['js']['mediainsert']     = 'แทรก';
+$lang['js']['mediadisplayimg'] = 'แสดงรูปภาพ';
+$lang['js']['mediadisplaylnk'] = 'แสดงลิงค์ เท่านั้น';
+$lang['js']['mediasmall']      = 'รูปแบบขนาดเล็ก';
+$lang['js']['mediamedium']     = 'รูปแบบขนาดกลาง';
+$lang['js']['medialarge']      = 'รูปแบบขนาดใหญ่';
+$lang['js']['mediaoriginal']   = 'รูปแบบตั้งต้น';
+$lang['js']['nosmblinks']      = 'เชื่อมไปยังหน้าต่างแบ่งปัน ทำงานได้กับเฉพาะไมโครซอฟท์อินเตอร์เน็ตเอ็กซโปรเรอร์(IE) คุณยังคงสามารถคัดลอกและแปะลิ้งค์ได้';
+$lang['js']['linkwiz']         = 'ลิงค์วิเศษ';
+$lang['js']['linkto']          = 'ลิงค์ไป:';
+$lang['js']['del_confirm']     = 'ต้องการลบรายการที่เลือกจริงๆหรือ?';
 $lang['rssfailed']             = 'มีข้อผิดพลาดขณะดูดฟีดนี้';
 $lang['nothingfound']          = 'ไม่พบสิ่งใด';
 $lang['mediaselect']           = 'ไฟล์สื่อ';
-$lang['fileupload']            = 'อัปโหลด';
 $lang['uploadsucc']            = 'อัปโหลดสำเร็จ';
 $lang['uploadfail']            = 'เกิดความขัดข้องในการอัปโหลด';
 $lang['uploadwrong']           = 'การอัพโหลดถูกปฏิเสธ ส่วนขยายไฟล์นี้ต้องห้าม!';
@@ -115,13 +146,6 @@ $lang['deletefail']            = '"%s" ไม่สามารถลบได
 $lang['mediainuse']            = 'ไฟล์ "%s" ไม่ได้ถูกลบ - มันถูกใช้อยู่';
 $lang['namespaces']            = 'เนมสเปซ';
 $lang['mediafiles']            = 'มีไฟล์พร้อมใช้อยู่ใน';
-$lang['js']['searchmedia']     = 'ค้นหาไฟล์';
-$lang['js']['keepopen']        = 'เปิดหน้าต่างไว้ระหว่างที่เลือก';
-$lang['js']['hidedetails']     = 'ซ่อนรายละเอียด';
-$lang['js']['nosmblinks']      = 'เชื่อมไปยังหน้าต่างแบ่งปัน ทำงานได้กับเฉพาะไมโครซอฟท์อินเตอร์เน็ตเอ็กซโปรเรอร์(IE) คุณยังคงสามารถคัดลอกและแปะลิ้งค์ได้';
-$lang['js']['linkwiz']         = 'ลิงค์วิเศษ';
-$lang['js']['linkto']          = 'ลิงค์ไป:';
-$lang['js']['del_confirm']     = 'ต้องการลบรายการที่เลือกจริงๆหรือ?';
 $lang['mediausage']            = 'ให้ใช้ไวยกรณ์ต่อไปนี้เพื่ออ้างอิงไฟล์นี้';
 $lang['mediaview']             = 'ดูไฟล์ต้นฉบับ';
 $lang['mediaroot']             = 'ราก(รูท)';
@@ -138,9 +162,9 @@ $lang['yours']                 = 'ฉบับของคุณ';
 $lang['diff']                  = 'แสดงจุดแตกต่างกับฉบับปัจจุบัน';
 $lang['diff2']                 = 'แสดงจุดแตกต่างระหว่างฉบับที่เลือกไว้';
 $lang['line']                  = 'บรรทัด';
-$lang['breadcrumb']            = 'ตามรอย';
-$lang['youarehere']            = 'คุณอยู่ที่นี่';
-$lang['lastmod']               = 'แก้ไขครั้งล่าสุด';
+$lang['breadcrumb']            = 'ตามรอย:';
+$lang['youarehere']            = 'คุณอยู่ที่นี่:';
+$lang['lastmod']               = 'แก้ไขครั้งล่าสุด:';
 $lang['by']                    = 'โดย';
 $lang['deleted']               = 'ถูกถอดออก';
 $lang['created']               = 'ถูกสร้าง';
@@ -178,27 +202,19 @@ $lang['qb_sig']                = 'ลายเซ็นพร้อมลงเ
 $lang['qb_smileys']            = 'ภาพแสดงอารมณ์';
 $lang['qb_chars']              = 'อักขระพิเศษ';
 $lang['upperns']               = 'กระโดดขึ้นไปยังเนมสเปซแม่';
-$lang['admin_register']        = 'สร้างบัญชีผู้ใช้';
 $lang['metaedit']              = 'แก้ไขข้อมูลเมต้า';
 $lang['metasaveerr']           = 'มีข้อผิดพลาดในการเขียนข้อมูลเมต้า';
 $lang['metasaveok']            = 'บันทึกเมต้าดาต้าแล้ว';
-$lang['img_backto']            = 'กลับไปยัง';
-$lang['img_title']             = 'ชื่อภาพ';
-$lang['img_caption']           = 'คำบรรยายภาพ';
-$lang['img_date']              = 'วันที่';
-$lang['img_fname']             = 'ชื่อไฟล์';
-$lang['img_fsize']             = 'ขนาดภาพ';
-$lang['img_artist']            = 'ผู้สร้างสรรค์';
-$lang['img_copyr']             = 'ผู้ถือลิขสิทธิ์';
-$lang['img_format']            = 'รูปแบบ';
-$lang['img_camera']            = 'กล้อง';
-$lang['img_keywords']          = 'คำหลัก';
-$lang['subscribe_success']     = 'เพิ่ม %s เข้าไปในรายชื่อสมาชิกลงทะเบียนสำหรับ %s';
-$lang['subscribe_error']       = 'มีข้อผิดพลาดในการเพิ่ม %s ในรายชื่อสมัครสมาชิกสำหรับ %s';
-$lang['subscribe_noaddress']   = 'ไม่มีที่อยู่ที่ตรงกับชื่อล็อกอินของคุณ ชื่อคุณไม่สามารถถูกเพิ่มเข้าไปในรายชื่อสมัครสมาชิก';
-$lang['unsubscribe_success']   = 'ถอด % ออกจากรายชื่อสมัครสมาชิกของ %s';
-$lang['unsubscribe_error']     = 'มีข้อผิดพลาดในการถอด %s ออกจากรายชื่อสมาชิกของ %s';
-$lang['authmodfailed']         = 'มีการกำหนดค่าสิทธิ์ผู้ใช้ไว้ไม่ดี กรุณาแจ้งผู้ดูแลระบบวิกิของคุณ';
+$lang['img_title']             = 'ชื่อภาพ:';
+$lang['img_caption']           = 'คำบรรยายภาพ:';
+$lang['img_date']              = 'วันที่:';
+$lang['img_fname']             = 'ชื่อไฟล์:';
+$lang['img_fsize']             = 'ขนาดภาพ:';
+$lang['img_artist']            = 'ผู้สร้างสรรค์:';
+$lang['img_copyr']             = 'ผู้ถือลิขสิทธิ์:';
+$lang['img_format']            = 'รูปแบบ:';
+$lang['img_camera']            = 'กล้อง:';
+$lang['img_keywords']          = 'คำหลัก:';
 $lang['authtempfail']          = 'ระบบตรวจสอบสิทธิ์ผู้ใช้ไม่พร้อมใช้งานชั่วคราว หากสถานการณ์ยังไม่เปลี่ยนแปลง กรุณาแจ้งผู้ดูแลระบวิกิของคุณ';
 $lang['i_chooselang']          = 'เลือกภาษาของคุณ';
 $lang['i_installer']           = 'ตัวติดตั้งโดกุวิกิ';
@@ -226,3 +242,5 @@ $lang['days']                  = '%d วันก่อน';
 $lang['hours']                 = '%d ชั่วโมงก่อน';
 $lang['minutes']               = '%d นาทีก่อน';
 $lang['seconds']               = '%d วินาทีก่อน';
+$lang['email_signature_text'] = 'จดหมายนี้ถูกสร้างขึ้นโดยโดกุวิกิที่
+@DOKUWIKIURL@';
