@@ -30,8 +30,6 @@ $lang['_notifications']        = 'Abisuen ezarpenak';
 $lang['_syndication']          = 'Sindikazio ezarpenak';
 $lang['_advanced']             = 'Ezarpen Aurreratuak';
 $lang['_network']              = 'Sare Ezarpenak';
-$lang['_plugin_sufix']         = 'Plugin Ezarpenak';
-$lang['_template_sufix']       = 'Txantiloi Ezarpenak';
 $lang['_msg_setting_undefined'] = 'Ezarpen metadaturik ez.';
 $lang['_msg_setting_no_class'] = 'Ezarpen klaserik ez.';
 $lang['_msg_setting_no_default'] = 'Balio lehenetsirik ez.';
@@ -52,7 +50,7 @@ $lang['breadcrumbs']           = 'Arrasto pauso kopurua';
 $lang['youarehere']            = 'Arrasto pauso hierarkikoak';
 $lang['fullpath']              = 'Orri oinean orrien bide osoa erakutsi';
 $lang['typography']            = 'Ordezkapen tipografikoak egin';
-$lang['dformat']               = 'Data formatua (ikusi PHPren <a href="http://www.php.net/strftime">strftime</a> funtzioa)';
+$lang['dformat']               = 'Data formatua (ikusi PHPren <a href="http://php.net/strftime">strftime</a> funtzioa)';
 $lang['signature']             = 'Sinadura';
 $lang['showuseras']            = 'Zer azaldu orri bat editatu duen azken erabiltzailea erakusterakoan';
 $lang['toptoclevel']           = 'Eduki taularen goiko maila';
@@ -97,7 +95,6 @@ $lang['target____media']       = 'Multimedia estekentzat helburu leihoa';
 $lang['target____windows']     = 'Leihoen estekentzat helburu leihoa';
 $lang['mediarevisions']        = 'Media rebisioak gaitu?';
 $lang['refcheck']              = 'Multimedia erreferentzia kontrolatu';
-$lang['refshow']               = 'Erakusteko multimedia erreferentzia kopurua';
 $lang['gdlib']                 = 'GD Lib bertsioa';
 $lang['im_convert']            = 'ImageMagick-en aldaketa tresnara bidea';
 $lang['jpg_quality']           = 'JPG konprimitze kalitatea (0-100)';
