@@ -43,8 +43,6 @@ $lang['_links']                = 'Innstillinger for lenker';
 $lang['_media']                = 'Innstillinger for mediafiler';
 $lang['_advanced']             = 'Avanserte innstillinger';
 $lang['_network']              = 'Nettverksinnstillinger';
-$lang['_plugin_sufix']         = '– innstillinger for tillegg';
-$lang['_template_sufix']       = '– innstillinger for mal';
 $lang['_msg_setting_undefined'] = 'Ingen innstillingsmetadata';
 $lang['_msg_setting_no_class'] = 'Ingen innstillingsklasse';
 $lang['_msg_setting_no_default'] = 'Ingen standard verdi';
@@ -66,7 +64,7 @@ $lang['youarehere']            = 'Vis hvor i hvilke(t) navnerom siden er';
 $lang['typography']            = 'Gjør typografiske erstatninger';
 $lang['htmlok']                = 'Tillat HTML';
 $lang['phpok']                 = 'Tillat PHP';
-$lang['dformat']               = 'Datoformat (se <a href="http://www.php.net/strftime">PHPs datofunksjon</a>)';
+$lang['dformat']               = 'Datoformat (se <a href="http://php.net/strftime">PHPs datofunksjon</a>)';
 $lang['signature']             = 'Signatur';
 $lang['toptoclevel']           = 'Toppnivå for innholdsfortegnelse';
 $lang['tocminheads']           = 'Minimum antall overskrifter som bestemmer om innholdsbetegnelse skal bygges.';
@@ -76,7 +74,6 @@ $lang['camelcase']             = 'Gjør KamelKasse til lenke automatisk';
 $lang['deaccent']              = 'Rensk sidenavn';
 $lang['useheading']            = 'Bruk første overskrift som tittel';
 $lang['refcheck']              = 'Sjekk referanser før mediafiler slettes';
-$lang['refshow']               = 'Antall viste referanser til mediafiler';
 $lang['allowdebug']            = 'Tillat feilsøking <b>skru av om det ikke behøves!</b>';
 $lang['mediarevisions']        = 'Slå på mediaversjonering?';
 $lang['usewordblock']          = 'Blokker søppel basert på ordliste';
